==> haskell-zinza-0.2.1-11.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-zinza.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 zinza
version:              0.2.1
visibility:           public
id:                   zinza-0.2.1-6HFiXi7KBZG1FeAmSXbbDE
key:                  zinza-0.2.1-6HFiXi7KBZG1FeAmSXbbDE
license:              GPL-2.0-or-later
copyright:            (c) 2019 Oleg Grenrus
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg.Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/zinza
synopsis:             Typed templates with jinja like syntax
description:
    Typed templates with jinja like syntax. Well-typed templates don'\''t go wrong.

category:             Text, Template
abi:                  63a03b9b6a5e2635061500f52d817136
exposed:              True
exposed-modules:      Zinza
hidden-modules:
    Zinza.Check Zinza.Class Zinza.Errors Zinza.Expr Zinza.Generic
    Zinza.Indexing Zinza.Module Zinza.Node Zinza.Parser Zinza.Pos
    Zinza.Type Zinza.Value Zinza.Var Zinza.Writer

import-dirs:          /usr/lib/ghc-9.6.6/site-local/zinza-0.2.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/zinza-0.2.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/zinza-0.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-zinza
hs-libraries:         HSzinza-0.2.1-6HFiXi7KBZG1FeAmSXbbDE
depends:
    base-4.18.2.1 containers-0.6.7 parsec-3.1.16.1 text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-zinza/html/zinza.haddock
haddock-html:         /usr/share/doc/haskell-zinza/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-zinza-0.2.1-12-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-zinza.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 zinza
version:              0.2.1
visibility:           public
id:                   zinza-0.2.1-AVnuymyAb2ZGRPTQizCLOa
key:                  zinza-0.2.1-AVnuymyAb2ZGRPTQizCLOa
license:              GPL-2.0-or-later
copyright:            (c) 2019 Oleg Grenrus
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg.Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/zinza
synopsis:             Typed templates with jinja like syntax
description:
    Typed templates with jinja like syntax. Well-typed templates don'\''t go wrong.

category:             Text, Template
abi:                  8995c752c33708a3ac46fe5e6c050247
exposed:              True
exposed-modules:      Zinza
hidden-modules:
    Zinza.Check Zinza.Class Zinza.Errors Zinza.Expr Zinza.Generic
    Zinza.Indexing Zinza.Module Zinza.Node Zinza.Parser Zinza.Pos
    Zinza.Type Zinza.Value Zinza.Var Zinza.Writer

import-dirs:          /usr/lib/ghc-9.6.6/site-local/zinza-0.2.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/zinza-0.2.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/zinza-0.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-zinza
hs-libraries:         HSzinza-0.2.1-AVnuymyAb2ZGRPTQizCLOa
depends:
    base-4.18.2.1 containers-0.6.7 parsec-3.1.16.1 text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-zinza/html/zinza.haddock
haddock-html:         /usr/share/doc/haskell-zinza/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
